Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.


Version 0.2.1 (2019-08-01)
--------------------------

Changed
~~~~~~~

* Remove os.system call for moving files (#43)

Fixed
~~~~~

* Remove broken logos from issue templates (#31)
* Wrong ``Spectrogram`` output shape in documentation (#40)
* Broken data set loading for relative paths (#33)


Version 0.2.0 (2019-06-28)
--------------------------

Added
~~~~~

* ``Standardize``, ``Log`` (#29)

Changed
~~~~~~~

* Switch to `Keep a Changelog`_ format (#34)

Deprecated
~~~~~~~~~~

* ``LogSpectrogram`` (#29)

Fixed
~~~~~

* ``normalize`` axis (#28)


Version 0.1.1 (2019-05-23)
--------------------------

Fixed
~~~~~

* Broken API documentation on RTD_


Version 0.1.0 (2019-05-22)
--------------------------

Added
~~~~~

* Public release


.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html
.. _RTD: https://audtorch.readthedocs.io/
